@@ -41,28 +41,33 @@ Briefly:
     library(reticulate)
 
     # -------------------------------------------------------------------------
-    # Import module via reticulate
+    # Set up reticulate
     # -------------------------------------------------------------------------
 
-    VENV <- "~/dev/venvs/cardinal_pythonlib"
-    PYTHON_VERSION <- "python3.5"
-    CARDINAL_PYTHONLIB_BASEDIR <- ifelse(
+    VENV <- "~/dev/venvs/cardinal_pythonlib"  # or your preferred virtualenv
+    PYTHON_EXECUTABLE <- ifelse(
         .Platform$OS.type == "windows",
-        file.path(VENV, "lib", "site-packages/cardinal_pythonlib"),
-        file.path(VENV, "lib", PYTHON_VERSION, "site-packages/cardinal_pythonlib")
+        file.path(VENV, "Scripts", "python.exe"),  # Windows
+        file.path(VENV, "bin", "python")  # Linux
     )
-    reticulate::use_virtualenv(VENV, required=TRUE)
+    reticulate::use_python(PYTHON_EXECUTABLE, required=TRUE)
 
-    # cpl_rfunc <- reticulate::import_from_path("rfunc", file.path(CARDINAL_PYTHONLIB_BASEDIR, "psychiatry"))
+    # -------------------------------------------------------------------------
+    # Import Python modules
+    # -------------------------------------------------------------------------
 
-    # Or, for development:
-    cpl_rfunc <- reticulate::import_from_path("rfunc", "~/Documents/code/cardinal_pythonlib/cardinal_pythonlib/psychiatry")
+    cpl_rfunc <- reticulate::import("cardinal_pythonlib.psychiatry.rfunc")
+
+    # -------------------------------------------------------------------------
+    # Try other things
+    # -------------------------------------------------------------------------
+    
+    repl_python()  # start an interactive Python session
 
 """  # noqa
 
-from typing import Any, Dict, Tuple
-
-from pandas import DataFrame
+import sys
+from typing import Any, Dict
 
 
 # =============================================================================
@@ -86,13 +91,23 @@ def get_python_repr(x: Any) -> str:
         )
         dt_repr <- cpl_rfunc$get_python_repr(dt)
 
-    gives
+    gives this when a duff import is used via
+    ``reticulate::import_from_path()``:
 
     .. code-block:: none
 
         [1] "{'drug': ['citalopram', 'Cipramil', 'Prozac', 'fluoxetine',
         'Priadel', 'Haldol'], 'subject': ['Alice', 'Bob', 'Charles', 'Dawn',
         'Egbert', 'Flora']}"
+
+    but this when a proper import is used via ``reticulate::import()``:
+
+    .. code-block:: none
+
+        [1] "   subject        drug\n0    Alice  citalopram\n1      Bob
+        Cipramil\n2  Charles      Prozac\n3     Dawn  fluoxetine\n4   Egbert
+         Priadel\n5    Flora      Haldol"
+
     """
     return repr(x)
 
@@ -105,11 +120,21 @@ def get_python_repr_of_type(x: Any) -> str:
 
         dt_type_repr <- cpl_rfunc$get_python_repr_of_type(dt)
 
-    gives
+    gives this when a duff import is used via
+    ``reticulate::import_from_path()``:
 
     .. code-block:: none
 
         [1] "<class 'dict'>"
+
+    but this when a proper import is used via ``reticulate::import()``:
+
+    .. code-block:: none
+
+        [1] "<class 'pandas.core.frame.DataFrame'>"
+
+    The same is true of a data.frame().
+
     """
     return repr(type(x))
 
@@ -144,14 +169,10 @@ def test_get_dict() -> Dict[str, Any]:
     }
 
 
-def test_get_repr_of_data_frame(df: DataFrame) -> Tuple[str, str, str]:
+def flush_stdout_stderr() -> None:
     """
-    Following on:
-
-    .. code-block:: r
-
-        dataframe <- as.data.frame(dt)
-        cpl_rfunc$test_get_repr_of_data_frame(dataframe)
+    R code won't see much unless we flush stdout/stderr manually.
+    See also https://github.com/rstudio/reticulate/issues/284
     """
-    df2 = DataFrame(df)
-    return repr(df2), repr(type(df2)), repr(type(df))
+    sys.stdout.flush()
+    sys.stderr.flush()
